%% FDI filter plotting
% This file generates the plots for \subsection{Results\Wind gusts} for the
% paper submitted to AIAA SciTech 2015.

%% Wind gust time marker
wg.time = [5; 5];
wg.ycoord = [-1e3, 1e3];

%% Fault injection time marker
fault.time = [20; 20];
fault.ycoord = [-1e3, 1e3];

%% Isolation & estimation time markers
IEplot.time = [IE.hittime; IE.hittime];
IEplot.ycoord = [-1e3, 1e3];

%% Global fault detection markers
t1 = 1:detect.hittime.globalind-1;
t2 = detect.hittime.globalind:numel(e.time);
alwayson = ones(length(t2),1);

%% Plot the error signals for detection
figure;

subplot(511); % beta
hold on;
fwi = plot(wg.time, [-1, -0.5], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-1, -0.5], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.beta);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fw = plot(e.time(t1), detect.sustain.beta(t1));
set(fw, 'LineStyle', '-', 'Color', 'g', 'LineWidth', 3);
ffd = plot(e.time(t2), alwayson);
set(ffd, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('\Delta \beta [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 60], 'YLim', [-1 5], ...
        'XTickLabel', [], 'YTick', -1:5, 'FontSize', 14, 'FontWeight', 'bold');
L1 = legend([fr, ffd], 'Residual', 'Fault detection', ...
        'Location', 'Best');
set(L1, 'FontSize', 14, 'FontWeight', 'bold');

subplot(512); % p
hold on;
fwi = plot(wg.time, [-8, -7], 'g-', 'LineWidth', 3);
plot(fault.time, [-8, -7], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.p);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fw = plot(e.time(t1), detect.sustain.p(t1));
set(fw, 'LineStyle', '-', 'Color', 'g', 'LineWidth', 3);
ffd = plot(e.time(t2), alwayson);
set(ffd, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('\Delta p [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 60], 'YLim', [-8 8], ...
        'XTickLabel', [], 'YTick', -8:4:8, 'FontSize', 14, 'FontWeight', 'bold');

subplot(513); % r
hold on;
fwi = plot(wg.time, [-10, -8.5], 'g-', 'LineWidth', 3);
plot(fault.time, [-10, -8.5], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.r);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fw = plot(e.time(t1), detect.sustain.r(t1));
set(fw, 'LineStyle', '-', 'Color', 'g', 'LineWidth', 3);
ffd = plot(e.time(t2), -1.*alwayson);
set(ffd, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('\Delta r [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 60], 'YLim', [-10 10], ...
        'XTickLabel', [], 'YTick', -10:5:10, 'FontSize', 14, 'FontWeight', 'bold');

%% Plot the error signals for isolation & estimation
subplot(514); % rudder
hold on;
fwi = plot(wg.time, [-15, -12.5], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-15, -12.5], 'm-', 'LineWidth', 3);
fIE = plot(IEplot.time, [-15, -12.5], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.rud);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fbrud = plot(SIL.time, SIL.b_rudder*r2d);
set(fbrud, 'LineStyle', '--', 'Color', 'k', 'LineWidth', 3);
frlpf = plot(IE.lpf.time, IE.lpf.rud);
set(frlpf, 'LineStyle', '--', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel( '\Delta \delta_{rud,cmd} [deg]', ...
        'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 60], 'YLim', [-15 15], ...
        'XTickLabel', [], 'YTick', -15:5:15, 'FontSize', 14, 'FontWeight', 'bold');
L1 = legend([fbrud], '\Delta \delta_{rud}^b', 'Location', 'Best');
set(L1, 'FontSize', 14, 'FontWeight', 'bold');

subplot(515); % aileron
hold on;
fwi = plot(wg.time, [-1.6, -1.5], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-1.6, -1.5], 'm-', 'LineWidth', 3);
fIE = plot(IEplot.time, [-1.6, -1.5], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.rail);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
frlpf = plot(IE.lpf.time, IE.lpf.rail);
set(frlpf, 'LineStyle', '--', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
xlabel('Time, t [s]', 'FontSize', 14, 'FontWeight', 'bold');
ylabel( '\Delta \delta_{ail,cmd}^r [deg]', ...
        'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 60], 'YLim', [-1.6 0.4], ...
        'YTick', -1.6:0.4:0.4, 'FontSize', 14, 'FontWeight', 'bold');
L2 = legend([frlpf], 'Filtered residual', 'Location', 'Best');
set(L2, 'FontSize', 14, 'FontWeight', 'bold');
