%% NL2_sim_vs_Lin_sim
% This file is used to validate the linearization that is carried out on
% the nonlinear model. The time responses of the linear model (from
% UAV_Lin.mdl) and two nonlinear models (from UAV_SIL.mdl) are compared
% here.

%% Clean up
close all
bdclose all
clc

%% Set variables of the nonlinear and linear responses
SIL_mod_1 = simres_NL_Ftp_cz;
SIL_mod_2 = simres_NL_Fbp_cz;
Lin_mod = simres_L_Uf_cz;
r2d = 180/pi;

%% Check that the files loaded are correct
SIL_mod_1.siminfo
SIL_mod_2.siminfo
Lin_mod.siminfo

if ~strcmp(SIL_mod_1.siminfo(1:7), 'SIL_sim')
    error('The model loaded into SIL_mod_1 is not from the SIL_sim.');
end
if ~strcmp(SIL_mod_2.siminfo(1:7), 'SIL_sim')
    error('The model loaded into SIL_mod_2 is not from the SIL_sim.');
end
if ~strcmp(Lin_mod.siminfo(1:7), 'Lin_sim')
    error('The model loaded into Lin_mod is not from the Lin_sim.');
end

%% Plot responses of the outputs
f1 = figure; % V, alpha, and beta
% subplot(311);
% plot(SIL_mod_1.time, SIL_mod_1.V_s, Lin_mod.time_L, Lin_mod.V_L + Lin_mod.TrimCondition.WindAxesIni(1));
% xlabel('Time, t [s]');
% ylabel('Airspeed, V [m/s]');
% legend('Nonlinear', 'Linear');
% subplot(312);
% plot(SIL_mod_1.time, SIL_mod_1.alpha*r2d, Lin_mod.time_L, Lin_mod.alpha_L + Lin_mod.TrimCondition.WindAxesIni(2)*r2d);
% xlabel('Time, t [s]');
% ylabel('Alpha, \alpha [deg]');
% legend('Nonlinear', 'Linear');
% subplot(313);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.beta*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.beta*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.beta_L + Lin_mod.TrimCondition.WindAxesIni(3)*r2d, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Beta, \beta [deg]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');

%%
figure; % phi, theta, and psi
subplot(211);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.phi*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.phi*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.phi_L + Lin_mod.TrimCondition.AttitudeIni(1)*r2d, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Phi, \phi [deg]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');
% subplot(312);
% plot(SIL_mod_1.time, SIL_mod_1.theta*r2d, Lin_mod.time_L, Lin_mod.theta_L + Lin_mod.TrimCondition.AttitudeIni(2)*r2d);
% xlabel('Time, t [s]');
% ylabel('Theta, \theta [deg]');
% legend('Nonlinear', 'Linear');
subplot(212);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.psi*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.psi*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.psi_L + Lin_mod.TrimCondition.AttitudeIni(3)*r2d, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Psi, \psi [deg]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');

figure; % p, q, and r
subplot(211);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.p*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.p*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.p_L, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Roll rate, p [deg/s]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');
% subplot(312);
% plot(SIL_mod_1.time, SIL_mod_1.q*r2d, Lin_mod.time_L, Lin_mod.q_L);
% xlabel('Time, t [s]');
% ylabel('Pitch rate, q [deg/s]');
% legend('Nonlinear', 'Linear');
subplot(212);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.r*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.r*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.r_L, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Yaw rate, r [deg/s]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');

%% Plot responses of the control commands
% figure; % throttle and elevator
% subplot(211);
% plot(SIL_mod_1.time, SIL_mod_1.throttle, Lin_mod.time_L, Lin_mod.throttle_L + Lin_mod.TrimCondition.Inputs.Throttle);
% xlabel('Time, t [s]');
% ylabel('Throttle, \tau [nd]');
% legend('Nonlinear', 'Linear');
% subplot(212);
% plot(SIL_mod_1.time, SIL_mod_1.elevator*r2d, Lin_mod.time_L, Lin_mod.elevator_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(1)*r2d);
% xlabel('Time, t [s]');
% ylabel('Elevator, elev [deg]');
% legend('Nonlinear', 'Linear');

figure; % rudder and aileron
subplot(211);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.rudder*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.rudder*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.rudder_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(2)*r2d, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Rudder, rud [deg]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');
subplot(212);
hold on;
plot(SIL_mod_1.time, SIL_mod_1.r_aileron*r2d, 'b-');
plot(SIL_mod_2.time, SIL_mod_2.r_aileron*r2d, 'r--');
plot(Lin_mod.time_L, Lin_mod.r_aileron_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(4)*r2d, 'k-.');
hold off;
xlabel('Time, t [s]');
ylabel('Aileron, r_{ail} [deg]');
legend('AC_{real}: top rudder fault', 'AC_{real}: bottom rudder fault', 'AC_{sim}', 'Location', 'Best');

%% Set line properties
line_han = findobj('Type','line');
set(line_han, 'LineWidth', 2);
